@@ -1,5 +1,7 @@
 """emcee-specific conversion code."""
 import warnings
+from collections import OrderedDict
+
 import xarray as xr
 import numpy as np
 
@@ -55,11 +57,11 @@ def _verify_names(sampler, var_names, arg_names, slices):
         warnings.warn(
             "Check slices: Not all parameters in chain captured. "
             "{} are present, and {} have been captured.".format(ndim, len(slicing_try)),
-            SyntaxWarning,
+            UserWarning,
         )
     if len(slicing_try) != len(set(slicing_try)):
         warnings.warn(
-            "Overlapping slices. Check the index present: {}".format(slicing_try), SyntaxWarning
+            "Overlapping slices. Check the index present: {}".format(slicing_try), UserWarning
         )
 
     if var_names is None:
@@ -145,7 +147,7 @@ class EmceeConverter:
                 "all arg_groups values should be either 'observed_data' or 'constant_data' "
                 ", not {}".format(bad_groups)
             )
-        obs_const_dict = {group: {} for group in arg_groups_set}
+        obs_const_dict = {group: OrderedDict() for group in arg_groups_set}
         for idx, (arg_name, group) in enumerate(zip(self.arg_names, self.arg_groups)):
             # Use emcee3 syntax, else use emcee2
             arg_array = np.atleast_1d(
@@ -165,41 +167,44 @@ class EmceeConverter:
         return obs_const_dict
 
     def blobs_to_dict(self):
-        """Convert blobs to dictionary {groupname: xr.Dataset}."""
-        # Omit blob conversion if blob_names is none.
-        # I should return {} instead of None when avoided
-        if self.blob_names is None:
-            return {}
-        elif self.blob_groups is None:
-            self.blob_groups = ["sample_stats" for _ in self.blob_names]
+        """Convert blobs to dictionary {groupname: xr.Dataset}.
+
+        It also stores lp values in sample_stats group.
+        """
+        store_blobs = not self.blob_names is None
+        self.blob_names = [] if self.blob_names is None else self.blob_names
+        if self.blob_groups is None:
+            self.blob_groups = ["log_likelihood" for _ in self.blob_names]
         if len(self.blob_names) != len(self.blob_groups):
             raise ValueError(
                 "blob_names and blob_groups must have the same length, or blob_groups be None"
             )
-        if int(self.emcee.__version__[0]) >= 3:
-            blobs = self.sampler.get_blobs()
-        else:
-            blobs = np.array(self.sampler.blobs)
-        if blobs is None or blobs.size == 0:
-            raise ValueError("No blobs in sampler, blob_names must be None")
-        if len(blobs.shape) == 2:
-            blobs = np.expand_dims(blobs, axis=-1)
-        blobs = blobs.swapaxes(0, 2)
-        nblobs, nwalkers, ndraws, *_ = blobs.shape
-        if len(self.blob_names) != nblobs and len(self.blob_names) != 1:
-            raise ValueError(
-                "Incorrect number of blob names. Expected {}, found {}".format(
-                    nblobs, len(self.blob_names)
+        if store_blobs:
+            if int(self.emcee.__version__[0]) >= 3:
+                blobs = self.sampler.get_blobs()
+            else:
+                blobs = np.array(self.sampler.blobs)
+            if (blobs is None or blobs.size == 0) and self.blob_names:
+                raise ValueError("No blobs in sampler, blob_names must be None")
+            if len(blobs.shape) == 2:
+                blobs = np.expand_dims(blobs, axis=-1)
+            blobs = blobs.swapaxes(0, 2)
+            nblobs, nwalkers, ndraws, *_ = blobs.shape
+            if len(self.blob_names) != nblobs and len(self.blob_names) > 1:
+                raise ValueError(
+                    "Incorrect number of blob names. Expected {}, found {}".format(
+                        nblobs, len(self.blob_names)
+                    )
                 )
-            )
         blob_groups_set = set(self.blob_groups)
+        blob_groups_set.add("sample_stats")
         idata_groups = ("posterior", "observed_data", "constant_data")
         if np.any(np.isin(list(blob_groups_set), idata_groups)):
             raise SyntaxError(
                 "{} groups should not come from blobs. Using them here would "
                 "overwrite their actual values".format(idata_groups)
             )
-        blob_dict = {group: {} for group in blob_groups_set}
+        blob_dict = {group: OrderedDict() for group in blob_groups_set}
         if len(self.blob_names) == 1:
             blob_dict[self.blob_groups[0]][self.blob_names[0]] = blobs.swapaxes(0, 2).swapaxes(0, 1)
         else:
@@ -213,6 +218,13 @@ class EmceeConverter:
                     blob = np.stack(blob)
                     blob = blob.reshape((nwalkers, ndraws, -1))
                 blob_dict[group][name] = np.squeeze(blob)
+
+        # store lp in sample_stats group
+        blob_dict["sample_stats"]["lp"] = (
+            self.sampler.get_log_prob().swapaxes(0, 1)
+            if hasattr(self.sampler, "get_log_prob")
+            else self.sampler.lnprobability
+        )
         for key, values in blob_dict.items():
             blob_dict[key] = dict_to_dataset(
                 values, library=self.emcee, coords=self.coords, dims=self.dims
@@ -264,7 +276,7 @@ def from_emcee(
         A list of the groups where blob_names variables
         should be assigned respectively. If blob_names!=None
         and blob_groups is None, all variables are assigned
-        to sample_stats group
+        to log_likelihood group
     coords : dict[str] -> list[str] (Optional)
         Map of dimensions to coordinates
     dims : dict[str] -> list[str] (Optional)
@@ -396,7 +408,8 @@ def from_emcee(
         >>> )
 
     Or in the case of even more complicated blobs, each corresponding to a different
-    group of the InferenceData object:
+    group of the InferenceData object. Moreover, the ``EnsembleSampler`` ``args`` argument
+    can be stored in observed or constant data groups if desired:
 
     .. plot::
         :context: close-figs
@@ -420,8 +433,9 @@ def from_emcee(
         >>>     var_names = ["mu", "tau", "eta"],
         >>>     slices=[0, 1, slice(2,None)],
         >>>     arg_names=["y","sigma"],
+        >>>     arg_groups=["observed_data", "constant_data"],
         >>>     blob_names=["log_likelihood", "y"],
-        >>>     blob_groups=["sample_stats", "posterior_predictive"],
+        >>>     blob_groups=["log_likelihood", "posterior_predictive"],
         >>>     dims=dims,
         >>>     coords={"school": range(8)}
         >>> )
