@@ -2,6 +2,7 @@
 import numpy as np
 
 from .plot_utils import _scale_fig_size, get_plotting_function
+from ..rcparams import rcParams
 
 
 def plot_compare(
@@ -26,8 +27,8 @@ def plot_compare(
 
     Notes
     -----
-    Defaults to comparing Widely Accepted Information Criterion (WAIC) if present in comp_df column,
-    otherwise compares Leave-one-out (loo)
+    Defaults to comparing Leave-one-out (psis-loo) if present in comp_df column,
+    otherwise compares Widely Applicable Information Criterion (WAIC)
 
 
     Parameters
@@ -101,7 +102,7 @@ def plot_compare(
 
     yticks_labels = [""] * len(yticks_pos)
 
-    _information_criterion = ["waic", "loo"]
+    _information_criterion = ["loo", "waic"]
     column_index = [c.lower() for c in comp_df.columns]
     for information_criterion in _information_criterion:
         if information_criterion in column_index:
@@ -134,6 +135,10 @@ def plot_compare(
         show=show,
     )
 
+    if backend is None:
+        backend = rcParams["plot.backend"]
+    backend = backend.lower()
+
     if backend == "bokeh":
 
         compareplot_kwargs["line_width"] = compareplot_kwargs.pop("linewidth")
